==> zio-aws-forecast_2.13-5.19.8.2-sources.jar: zio/aws/forecast/model/CreateExplainabilityExportRequest.scala <==
package zio.aws.forecast.model
import zio.ZIO
import zio.aws.forecast.model.primitives.{Format, Arn, Name}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateExplainabilityExportRequest(
    explainabilityExportName: Name,
    explainabilityArn: Arn,
    destination: zio.aws.forecast.model.DataDestination,
    tags: Optional[Iterable[zio.aws.forecast.model.Tag]] = Optional.Absent,
    format: Optional[Format] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.forecast.model.CreateExplainabilityExportRequest = {
    import CreateExplainabilityExportRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.forecast.model.CreateExplainabilityExportRequest
      .builder()
      .explainabilityExportName(
        Name.unwrap(explainabilityExportName): java.lang.String
      )
      .explainabilityArn(Arn.unwrap(explainabilityArn): java.lang.String)
      .destination(destination.buildAwsValue())
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        format.map(value => Format.unwrap(value): java.lang.String)
      )(_.format)
      .build()
  }
  def asReadOnly
      : zio.aws.forecast.model.CreateExplainabilityExportRequest.ReadOnly =
    zio.aws.forecast.model.CreateExplainabilityExportRequest
      .wrap(buildAwsValue())
}
object CreateExplainabilityExportRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.forecast.model.CreateExplainabilityExportRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.forecast.model.CreateExplainabilityExportRequest =
      zio.aws.forecast.model.CreateExplainabilityExportRequest(
        explainabilityExportName,
        explainabilityArn,
        destination.asEditable,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        format.map(value => value)
      )
    def explainabilityExportName: Name
    def explainabilityArn: Arn
    def destination: zio.aws.forecast.model.DataDestination.ReadOnly
    def tags: Optional[List[zio.aws.forecast.model.Tag.ReadOnly]]
    def format: Optional[Format]
    def getExplainabilityExportName: ZIO[Any, Nothing, Name] =
      ZIO.succeed(explainabilityExportName)
    def getExplainabilityArn: ZIO[Any, Nothing, Arn] =
      ZIO.succeed(explainabilityArn)
    def getDestination
        : ZIO[Any, Nothing, zio.aws.forecast.model.DataDestination.ReadOnly] =
      ZIO.succeed(destination)
    def getTags: ZIO[Any, AwsError, List[zio.aws.forecast.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getFormat: ZIO[Any, AwsError, Format] =
      AwsError.unwrapOptionField("format", format)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.forecast.model.CreateExplainabilityExportRequest
  ) extends zio.aws.forecast.model.CreateExplainabilityExportRequest.ReadOnly {
    override val explainabilityExportName: Name =
      zio.aws.forecast.model.primitives.Name(impl.explainabilityExportName())
    override val explainabilityArn: Arn =
      zio.aws.forecast.model.primitives.Arn(impl.explainabilityArn())
    override val destination: zio.aws.forecast.model.DataDestination.ReadOnly =
      zio.aws.forecast.model.DataDestination.wrap(impl.destination())
    override val tags: Optional[List[zio.aws.forecast.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.forecast.model.Tag.wrap(item)
          }.toList
        )
    override val format: Optional[Format] = zio.aws.core.internal
      .optionalFromNullable(impl.format())
      .map(value => zio.aws.forecast.model.primitives.Format(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.forecast.model.CreateExplainabilityExportRequest
  ): zio.aws.forecast.model.CreateExplainabilityExportRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-forecast_3-5.17.186.1-sources.jar: zio/aws/forecast/model/CreateExplainabilityExportRequest.scala <==
package zio.aws.forecast.model
import zio.ZIO
import zio.aws.forecast.model.primitives.{Arn, Name}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateExplainabilityExportRequest(
    explainabilityExportName: Name,
    explainabilityArn: Arn,
    destination: zio.aws.forecast.model.DataDestination,
    tags: Optional[Iterable[zio.aws.forecast.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.forecast.model.CreateExplainabilityExportRequest = {
    import CreateExplainabilityExportRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.forecast.model.CreateExplainabilityExportRequest
      .builder()
      .explainabilityExportName(
        Name.unwrap(explainabilityExportName): java.lang.String
      )
      .explainabilityArn(Arn.unwrap(explainabilityArn): java.lang.String)
      .destination(destination.buildAwsValue())
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly
      : zio.aws.forecast.model.CreateExplainabilityExportRequest.ReadOnly =
    zio.aws.forecast.model.CreateExplainabilityExportRequest
      .wrap(buildAwsValue())
}
object CreateExplainabilityExportRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.forecast.model.CreateExplainabilityExportRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.forecast.model.CreateExplainabilityExportRequest =
      zio.aws.forecast.model.CreateExplainabilityExportRequest(
        explainabilityExportName,
        explainabilityArn,
        destination.asEditable,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def explainabilityExportName: Name
    def explainabilityArn: Arn
    def destination: zio.aws.forecast.model.DataDestination.ReadOnly
    def tags: Optional[List[zio.aws.forecast.model.Tag.ReadOnly]]
    def getExplainabilityExportName: ZIO[Any, Nothing, Name] =
      ZIO.succeed(explainabilityExportName)
    def getExplainabilityArn: ZIO[Any, Nothing, Arn] =
      ZIO.succeed(explainabilityArn)
    def getDestination
        : ZIO[Any, Nothing, zio.aws.forecast.model.DataDestination.ReadOnly] =
      ZIO.succeed(destination)
    def getTags: ZIO[Any, AwsError, List[zio.aws.forecast.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.forecast.model.CreateExplainabilityExportRequest
  ) extends zio.aws.forecast.model.CreateExplainabilityExportRequest.ReadOnly {
    override val explainabilityExportName: Name =
      zio.aws.forecast.model.primitives.Name(impl.explainabilityExportName())
    override val explainabilityArn: Arn =
      zio.aws.forecast.model.primitives.Arn(impl.explainabilityArn())
    override val destination: zio.aws.forecast.model.DataDestination.ReadOnly =
      zio.aws.forecast.model.DataDestination.wrap(impl.destination())
    override val tags: Optional[List[zio.aws.forecast.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.forecast.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.forecast.model.CreateExplainabilityExportRequest
  ): zio.aws.forecast.model.CreateExplainabilityExportRequest.ReadOnly =
    new Wrapper(impl)
}
